<?php

if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

class Crea_ThemePlugin_Icon_Mixin {

	private static $instance = null;
	protected $namespace = '';

	public static function get_instance() {
		if ( null === static::$instance ) {
			static::$instance = new static();
		}
			
		return static::$instance;
	}

	public function get_vc_map_array( $group_name = null ) {
		// Check if Visual Composer is installed
		if ( ! defined( 'WPB_VC_VERSION' ) ) {
			return;
		}

		$vc_map_array = array(
            array(
                'type' => 'dropdown',
                'heading' => __( 'Icon library', 'airpro' ),
                'param_name' => 'target_icon_library',
                'value' => array(
                    __( 'Theme Icons', 'airpro' ) => 'crea-theme-icons',
                    __( 'Font Awesome', 'airpro' ) => 'fontawesome'
                ),
                'description' => __( 'Select icon library.', 'airpro' ),
            ),
            array(
                'type'        => 'iconpicker',
                'param_name'  => 'theme_icon',
                'heading'     => __( 'Icon', 'airpro' ),
                'value'       => '', // default value to backend editor admin_label
                'class'       => 'scp-theme-icon-name',
                'holder'      => 'div',
                'settings'    => array(
                    'emptyIcon'    => true,
                    'type'         => 'theme-icons',
                    'iconsPerPage' => 350, // default 100, how many icons per/page to display, we can use (big number) to display all icons in single page
                ),
                'admin_label' => true,
                'description' => __( 'Select icon from library.', 'airpro' ),
                'dependency' => array( 'element' => 'target_icon_library', 'value' => 'crea-theme-icons' )
            ),
            array(
                'type'        => 'iconpicker',
                'param_name'  => 'fontawesome_icon',
                'heading'     => __( 'FontAwesome Icon', 'airpro' ),
                'value'       => '', // default value to backend editor admin_label
                'class'       => 'scp-theme-icon-name',
                'holder'      => 'div',
                'settings'    => array(
                    'emptyIcon'    => true,
                    'type'         => 'fontawesome', //'theme-icons',
                    'iconsPerPage' => 350, // default 100, how many icons per/page to display, we can use (big number) to display all icons in single page
                ),
                'admin_label' => true,
                'description' => __( 'Select icon from library.', 'airpro' ),
                'dependency' => array( 'element' => 'target_icon_library', 'value' => 'fontawesome' )
            ),

            // Styling
            array(
                'type'        => 'textfield',
                'heading'     => __( 'Font Size', 'airpro' ),
                'param_name'  => 'icon_font_size',
                'description' => __( 'Value in px. Enter number only.', 'airpro' ),
                'group'      => __( 'Styling', 'airpro' )
            ),
            array(
                'type'       => 'dropdown',
                'class'      => '',
                'heading'    => __( 'Use Border?', 'airpro' ),
                'param_name' => 'use_border',
                'value'      => array(
                    'No'  => '0',
                    'Yes' => '1',
                ),
                'group'      => __( 'Styling', 'airpro' )
            ),
            array(
                'type'       => 'textfield',
                'holder'     => '',
                'class'      => 'vc_col-xs-6',
                'heading'    => __( 'Border Width (in px)', 'airpro' ),
                'param_name' => 'icon_border_width',
                'group' => __( 'Styling', 'airpro' ),
                'dependency'  => array( 'element' => 'use_border', 'value' => array( '1' ) )
            ),
            array(
                'type'        => 'textfield',
                'heading'     => __( 'Border Radius', 'airpro' ),
                'param_name'  => 'border_radius',
                'description' => __( 'Value in px. Enter number only.', 'airpro' ),
                'group'      => __( 'Styling', 'airpro' )
            ),
            array(
                'type'       => 'dropdown',
                'class'      => '',
                'heading'    => __( 'Apply Shadow?', 'airpro' ),
                'param_name' => 'inner_box_shadow',
                'value'      => array(
                    'No'  => '0',
                    'Yes' => '1',
                ),
                'group'      => __( 'Styling', 'airpro' )
            ),
            array(
                'type'       => 'textfield',
                'holder'     => '',
                'class'      => 'vc_col-xs-6',
                'heading'    => __( 'Icon Padding - Top (in px)', 'airpro' ),
                'param_name' => 'icon_padding_top',
                'group' => __( 'Icon', 'airpro' ),
                'edit_field_class' => 'vc_col-sm-6'
            ),
            array(
                'type'       => 'textfield',
                'holder'     => '',
                'class'      => 'vc_col-xs-6',
                'heading'    => __( 'Icon Padding - Right (in px)', 'airpro' ),
                'param_name' => 'icon_padding_right',
                'group' => __( 'Icon', 'airpro' ),
                'edit_field_class' => 'vc_col-sm-6'
            ),
            array(
                'type'       => 'textfield',
                'holder'     => '',
                'class'      => 'vc_col-xs-6',
                'heading'    => __( 'Icon Padding - Bottom (in px)', 'airpro' ),
                'param_name' => 'icon_padding_bottom',
                'group' => __( 'Icon', 'airpro' ),
                'edit_field_class' => 'vc_col-sm-6'
            ),
            array(
                'type'       => 'textfield',
                'holder'     => '',
                'class'      => 'vc_col-xs-6',
                'heading'    => __( 'Icon Padding - Left (in px)', 'airpro' ),
                'param_name' => 'icon_padding_left',
                'group' => __( 'Icon', 'airpro' ),
                'edit_field_class' => 'vc_col-sm-6'
            ),
            array(
                'type'        => 'checkbox',
                'heading'     => __( 'Render as Circle?', 'airpro' ),
                'param_name'  => 'render_as_circle',
                'description' => __( 'If this option is set, the element will be rendered as a circle (rounded corners and proportional to the font size).', 'airpro' ),
                'choices' => array(
                    1 => esc_html__( 'Yes', 'airpro' ),
                ),
                'default_value' => '',
                'group'      => __( 'Styling', 'airpro' )
            ),
            array(
                'type'        => 'textfield',
                'heading'     => __( 'Circle Size (in em)', 'airpro' ),
                'param_name'  => 'background_circle_size',
                'description' => __( 'Circle size, relative to the font size. E.g. if entered "2", that will be rendered as "2em", which is a doubled font size. Enter number only.', 'airpro' ),
                'value' => '2.4',
                'dependency' => array( 'element' => 'render_as_circle', 'not_empty' => true ),
                'group'      => __( 'Styling', 'airpro' )
            ),

            // Colors
            array(
                'type'       => 'colorpicker',
                'heading'    => __( 'Background Color', 'airpro' ),
                'param_name' => 'inner_background_color',
                'description' => __( 'Will not be used if "Apply Theme Primary Styling Color To" is set to "Background".', 'airpro' ),
                'group'      => __( 'Colors', 'airpro' )
            ),
            array(
                'type'       => 'colorpicker',
                'heading'    => __( 'Background Hover Color', 'airpro' ),
                'param_name' => 'inner_background_hover_color',
                'description' => __( 'Will not be used if "Apply Theme Primary Styling Color on Hover To" is set to "Background".', 'airpro' ),
                'group'      => __( 'Colors', 'airpro' )
            ),
            array(
                'type'       => 'colorpicker',
                'heading'    => __( 'Border Color', 'airpro' ),
                'param_name' => 'border_color',
                'dependency' => array( 'element' => 'use_border', 'value' => array( '1' ) ),
                'group'      => __( 'Colors', 'airpro' )
            ),
            array(
                'type'       => 'colorpicker',
                'heading'    => __( 'Border Hover Color', 'airpro' ),
                'param_name' => 'icon_border_hover_color',
                'dependency' => array( 'element' => 'use_border', 'value' => array( '1' ) ),
                'group'      => __( 'Colors', 'airpro' )
            ),
            array(
                'type'        => 'colorpicker',
                'heading'     => __( 'Icon Color', 'airpro' ),
                'param_name'  => 'color',
                'description' => __( 'Will not be used if "Apply Theme Primary Styling Color To" is set to "Text".', 'airpro' ),
                'group'      => __( 'Colors', 'airpro' )
            ),
            array(
                'type'        => 'colorpicker',
                'heading'     => __( 'Icon Hover Color', 'airpro' ),
                'param_name'  => 'hover_color',
                'description' => __( 'Will not be used if "Apply Theme Primary Styling Color on Hover To" is set to "Text".', 'airpro' ),
                'group'      => __( 'Colors', 'airpro' )
            )
        );

        if ( ! empty( $group_name ) ) {
            $this->apply_group_name_to_all_vc_map_items( $vc_map_array, $group_name );
        }

        return $vc_map_array;
    }

    public function get_theme_styling_target_values() {
        return array(
            __( 'Icon', 'airpro' ) => 'icon',
            __( 'Icon Background', 'airpro' ) => 'icon_background'
        );
    }
	
	public function get_render( $atts, $content = null ) {
        
		$defaults = $this->get_default_settings_values();

		$shortcode_atts = shortcode_atts( $defaults, $atts );

		extract( $shortcode_atts );

		$class_of_inner_wrapper = array( 'crea-vc-icon-inner-wrapper' );
		$class_of_inner_tag = array(
			'crea-vc-icon-tag',
			$this->get_selected_icon( $shortcode_atts )
		);

		if ( $inner_box_shadow ) {
			$class_of_inner_wrapper[] = 'crea-vc-icon-shadow';
		}
		
		if ( $shortcode_atts[ 'render_as_circle' ] ) {
			$class_of_inner_wrapper[] = 'crea-circle-icon';
		}

		ob_start();
		?>

				<div class="<?php echo implode( ' ', $class_of_inner_wrapper ); ?>">

					<i class="<?php echo implode( ' ', $class_of_inner_tag ); ?>">
					</i>
 
				</div>	<!-- .crea-vc-icon-inner-wrapper -->

		<?php
		$content = ob_get_clean();

		return $content;
	}

	public function get_icon_classes( $params ) {
		$classes = array( 'crea-vc-icon' );

		return implode( ' ', $classes );
    }
    
    public function get_inline_styles_based_on_settings( $unique_container_selector, $shortcode_atts ) {
        $inline_css = array();
        
        $theme_primary_styling_color = function_exists( 'airpro_get_option' )
			? airpro_get_option( 'primary-styling-color' )
			: '';
		$theme_secondary_styling_color = function_exists( 'airpro_get_option' )
			? airpro_get_option( 'secondary-styling-color' )
			: '';

		if ( $shortcode_atts[ 'use_border' ] && $shortcode_atts[ 'border_color' ] && $shortcode_atts[ 'icon_border_width' ] ) {
			$inline_css[] = sprintf( '%1$s .crea-vc-icon-inner-wrapper { border:%2$s solid %3$s; }',
				$unique_container_selector,
                scp_sanitize_size( $shortcode_atts[ 'icon_border_width' ] ),
				$shortcode_atts[ 'border_color' ]
			);
        }
        
        if ( $shortcode_atts[ 'icon_border_hover_color' ] ) {
            $inline_css[] = sprintf( '%1$s:hover .crea-vc-icon-inner-wrapper, %3$s:hover %1$s .crea-vc-icon-inner-wrapper { border-color: %2$s !important; }',
				$unique_container_selector,
				$shortcode_atts[ 'icon_border_hover_color' ],
				'.crea-container-which-triggers-theme-styling-on-children'
			);
        }

        $new_border_radius = scp_extract_number_string_from_input_text( $shortcode_atts[ 'border_radius' ] );
        if ($new_border_radius) {
            $inline_css[] = sprintf( '%1$s .crea-vc-icon-inner-wrapper { border-radius: %2$s; }',
                $unique_container_selector,
                scp_sanitize_size( $new_border_radius )
            );
        }
		
		// icon paddings
		$should_render_icon_paddings =
            $shortcode_atts[ 'icon_padding_top' ]
            || $shortcode_atts[ 'icon_padding_right' ]
            || $shortcode_atts[ 'icon_padding_bottom' ]
            || $shortcode_atts[ 'icon_padding_left' ];
        if ( $should_render_icon_paddings ) {
            $icon_paddings = sprintf( '%1$s .crea-vc-icon-inner-wrapper { ', $unique_container_selector );

            if ( ! empty( $shortcode_atts[ 'icon_padding_top' ] ) ) {
                $icon_paddings .= sprintf(
                    'padding-top: %1$spx; ',
                    scp_extract_number_string_from_input_text( $shortcode_atts[ 'icon_padding_top' ] )
                );
            }

            if ( ! empty( $shortcode_atts[ 'icon_padding_right' ] ) ) {
                $icon_paddings .= sprintf(
                    'padding-right: %1$spx; ',
                    scp_extract_number_string_from_input_text( $shortcode_atts[ 'icon_padding_right' ] )
                );
            }

            if ( ! empty( $shortcode_atts[ 'icon_padding_bottom' ] ) ) {
                $icon_paddings .= sprintf(
                    'padding-bottom: %1$spx; ',
                    scp_extract_number_string_from_input_text( $shortcode_atts[ 'icon_padding_bottom' ] )
                );
            }

            if ( ! empty( $shortcode_atts[ 'icon_padding_left' ] ) ) {
                $icon_paddings .= sprintf(
                    'padding-left: %1$spx; ',
                    scp_extract_number_string_from_input_text( $shortcode_atts[ 'icon_padding_left' ] )
                );
            }

            $icon_paddings .= ' }';

            $inline_css[] = $icon_paddings;
        }

        $should_apply_back_color = $shortcode_atts[ 'inner_background_color' ];
		if ( $should_apply_back_color ) {
			$inline_css[] = sprintf( '%1$s .crea-vc-icon-inner-wrapper { background-color: %2$s; }',
				$unique_container_selector,
				$shortcode_atts[ 'inner_background_color' ]
			);
		}

		if ( $shortcode_atts[ 'render_as_circle' ] ) {
			$circle_size = scp_sanitize_size( $shortcode_atts[ 'background_circle_size' ], 'em', 2.4, 'float' );
			$inline_css[] = sprintf( '%1$s .crea-vc-icon-inner-wrapper { width: %2$s; height: %2$s; }',
				$unique_container_selector,
				$circle_size
			);
		}
		
		if ( $shortcode_atts[ 'icon_font_size' ] ) {
			$inline_css[] = sprintf( '%1$s .crea-vc-icon-inner-wrapper { font-size: %2$s; }',
				$unique_container_selector,
				scp_sanitize_size( $shortcode_atts[ 'icon_font_size' ] )
			);
		}

		if ( $shortcode_atts[ 'color' ] ) {
			$inline_css[] = sprintf( '%1$s .crea-vc-icon-inner-wrapper { color: %2$s; }',
				$unique_container_selector,
				$shortcode_atts[ 'color' ]
			);
		}

        $should_apply_color_on_hover = $shortcode_atts[ 'hover_color' ];
		if ( $should_apply_color_on_hover ) {
			$new_hover_color = $shortcode_atts[ 'hover_color' ];
			$inline_css[] = sprintf( '%1$s:hover .crea-vc-icon-inner-wrapper, %3$s:hover %1$s .crea-vc-icon-inner-wrapper { color: %2$s !important; }',
				$unique_container_selector,
				$new_hover_color,
				'.crea-container-which-triggers-theme-styling-on-children'
			);
		}

        $should_apply_background_color_on_hover = $shortcode_atts[ 'inner_background_hover_color' ];
		if ( $should_apply_background_color_on_hover ) {
			$new_background_hover_color = $shortcode_atts[ 'inner_background_hover_color' ];
			$inline_css[] = sprintf( '%1$s:hover .crea-vc-icon-inner-wrapper, %3$s:hover %1$s .crea-vc-icon-inner-wrapper { background-color: %2$s !important; }',
				$unique_container_selector,
				$new_background_hover_color,
				'.crea-container-which-triggers-theme-styling-on-children'
			);
		}
		
		if ( scp_design_fragment_affected_by_theme_styling( $shortcode_atts, 'icon', 'primary' ) ) {
            $inline_css[] = sprintf(
				'%1$s .crea-vc-icon-inner-wrapper { color: %2$s !important; }',
				$unique_container_selector,
				$theme_primary_styling_color
			);
		}
		if ( scp_design_fragment_affected_by_theme_styling( $shortcode_atts, 'icon', 'secondary' ) ) {
            $inline_css[] = sprintf(
				'%1$s .crea-vc-icon-inner-wrapper { color: %2$s !important; }',
				$unique_container_selector,
				$theme_secondary_styling_color
			);
		}
		if ( scp_design_fragment_affected_by_theme_styling( $shortcode_atts, 'icon_background', 'primary' ) ) {
            $inline_css[] = sprintf(
				'%1$s .crea-vc-icon-inner-wrapper { background-color: %2$s !important; }',
				$unique_container_selector,
				$theme_primary_styling_color
			);
		}
		if ( scp_design_fragment_affected_by_theme_styling( $shortcode_atts, 'icon_background', 'secondary' ) ) {
            $inline_css[] = sprintf(
				'%1$s .crea-vc-icon-inner-wrapper { background-color: %2$s !important; }',
				$unique_container_selector,
				$theme_secondary_styling_color
			);
		}
		if ( scp_design_fragment_affected_by_theme_styling( $shortcode_atts, 'icon', 'primary_hover' ) ) {
            $inline_css[] = sprintf(
				'%1$s:hover .crea-vc-icon-inner-wrapper, %3$s:hover %1$s .crea-vc-icon-inner-wrapper { color: %2$s !important; }',
				$unique_container_selector,
				$theme_primary_styling_color,
				'.crea-container-which-triggers-theme-styling-on-children'
			);
		}
		if ( scp_design_fragment_affected_by_theme_styling( $shortcode_atts, 'icon', 'secondary_hover' ) ) {
            $inline_css[] = sprintf(
				'%1$s:hover .crea-vc-icon-inner-wrapper, %3$s:hover %1$s .crea-vc-icon-inner-wrapper { color: %2$s !important; }',
				$unique_container_selector,
				$theme_secondary_styling_color,
				'.crea-container-which-triggers-theme-styling-on-children'
			);
		}
		if ( scp_design_fragment_affected_by_theme_styling( $shortcode_atts, 'icon_background', 'primary_hover' ) ) {
            $inline_css[] = sprintf(
				'%1$s:hover .crea-vc-icon-inner-wrapper, %3$s:hover %1$s .crea-vc-icon-inner-wrapper { background-color: %2$s !important; }',
				$unique_container_selector,
				$theme_primary_styling_color,
				'.crea-container-which-triggers-theme-styling-on-children'
			);
		}
		if ( scp_design_fragment_affected_by_theme_styling( $shortcode_atts, 'icon_background', 'secondary_hover' ) ) {
            $inline_css[] = sprintf(
				'%1$s:hover .crea-vc-icon-inner-wrapper, %3$s:hover %1$s .crea-vc-icon-inner-wrapper { background-color: %2$s !important; }',
				$unique_container_selector,
				$theme_secondary_styling_color,
				'.crea-container-which-triggers-theme-styling-on-children'
			);
		}

		return $inline_css;
	}

	public function get_default_settings_values() {
		return array(
			'target_icon_library'         => '',
			'theme_icon'         => '',
			'fontawesome_icon'         => '',
			// Styling
			'icon_font_size'     => '',
			'inner_box_shadow'         => '',
			'use_border'         => '',
			'icon_border_width'      => '',
			'border_radius'      => '',
			'icon_padding_top' => '',
			'icon_padding_right' => '',
			'icon_padding_bottom' => '',
			'icon_padding_left' => '',
			'render_as_circle'  => '',
			'background_circle_size'            => '2.4',
			// Colors
			'color'              => '',
			'hover_color'        => '',
			'inner_background_color'       => '',
			'inner_background_hover_color'       => '',
			'border_color'       => '',
			'icon_border_hover_color'       => ''
		);
    }
    
    private function apply_group_name_to_all_vc_map_items( &$vc_map_array, $group_name ) {
        foreach ( $vc_map_array as &$vc_map_item ) {
            $vc_map_item[ 'group' ] = $group_name;
        }
    }

    public function get_selected_icon( $shortcode_atts ) {
		$res = $shortcode_atts[ 'theme_icon' ];
		if ( empty( $res ) ) {
			$res = $shortcode_atts[ 'fontawesome_icon' ];
		}

		return $res;
	}
}

Crea_ThemePlugin_Icon_Mixin::get_instance();