<?php
if ( ! defined( 'ABSPATH' ) ) {
	die( '-1' );
}

class Scp_Theme_Social_share_button {

	protected $name = 'Theme Social Share Button';
	protected $namespace = 'scp_theme_social_share_button';
    protected $unique_random_number = 0;

	function __construct() {
		add_action( 'init', array( $this, 'integrateWithVC' ) );
		add_shortcode( $this->namespace, array( $this, 'render' ) );
		add_action( 'wp_enqueue_scripts', array( $this, 'loadCssAndJs' ) );
		add_action( 'admin_enqueue_scripts', array( $this, 'loadAdminCssAndJs' ) );
	}

	public function integrateWithVC() {
		if ( ! defined( 'WPB_VC_VERSION' ) ) {
			return;
		}

		$group_name_for_icon_settings = __( 'Icon', 'airpro' );

		$theme_styling_target_fields = array_merge(
			Crea_ThemePlugin_Icon_Mixin::get_instance()->get_theme_styling_target_values()
		);

		$params = array_merge(
			array(
				array(
					'type'        => 'dropdown',
					'heading'     => __( 'Type of Sharing', 'airpro' ),
					'param_name'  => 'sharing_type',
					'save_always' => true,
					'value'       => array(
						__( 'Faceboook', 'airpro' ) => 'facebook',
						__( 'Twitter', 'airpro' ) => 'twitter',
						__( 'Google+', 'airpro' )  => 'googleplus',
						__( 'Pinterest', 'airpro' )  => 'pinterest',
						__( 'Tumblr', 'airpro' )  => 'tumblr',
						__( 'LinkedIn', 'airpro' ) => 'linkedin',
						__( 'Reddit', 'airpro' )  => 'reddit',
						__( 'Via E-Mail', 'airpro' ) => 'email'
					),
					'admin_label' => true,
					'description' => __( 'Specifies the channel used for sharing content.', 'airpro' )
				),
				array(
					'type'       => 'checkbox',
					'heading'    => __( 'Position Absolute?', 'airpro' ),
					'param_name' => 'position_absolute',
				),
				array(
					'type'       => 'dropdown',
					'holder'     => '',
					'class'      => '',
					'heading'    => __( 'Float Inside Container', 'airpro' ),
					'param_name' => 'float_inside_container',
					'value'      => array(
						'left'   => 'left',
						'center' => 'center',
						'right'  => 'right',
					),
					'description' => __( 'Alignment inside the container (i.e. a float behavior).', 'airpro' )
				),
				array(
					'type'        => 'textfield',
					'param_name'  => 'el_class',
					'heading'     => __( 'Extra class name', 'airpro' ),
					'description' => __( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'airpro' ),
				)
			),

			Crea_ThemePlugin_Icon_Mixin::get_instance()->get_vc_map_array( $group_name_for_icon_settings ),

			array(
				// CSS
				array(
					'type'       => 'css_editor',
					'heading'    => __( 'CSS box', 'airpro' ),
					'param_name' => 'css',
					'group'      => __( 'Design Options', 'airpro' ),
				)
			)
		);

		vc_map( array(
			'name'             => esc_html( $this->name, 'airpro' ),
			'description' => __( 'Generates "share" link for the selected channel (social networks, e-mail, ...).', 'airpro' ),
			'base'             => $this->namespace,
			'class'            => '',
			'controls'         => 'full',
			'icon'             => plugins_url( 'assets/creatopus-vc-icon.png', __FILE__ ),
			'category'         => __( 'Creatopus', 'airpro' ),
			'admin_enqueue_js' => array(
				plugins_url( 'assets/admin-theme-social-share-button.js', __FILE__ ),
				plugins_url( 'assets/admin-theme-icon.js', __FILE__ )
			),
			'params' => $params
		) );
	}
	
	public function render( $atts, $content = null ) {
        
        $this->generate_unique_id();
		
		$defaults = $this->get_default_settings_values();

		$shortcode_atts = shortcode_atts( $defaults, $atts );

		extract( $shortcode_atts );

        $this->enqueue_js_css_if_shortcode_found_on_page( $shortcode_atts );

		$class_to_filter = $this->get_main_addon_container_classes( $shortcode_atts );
		$css_class = apply_filters( VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, $class_to_filter . ' ' . $el_class, $this->namespace, $atts );

		$icon_classes = $this->get_icon_classes( $shortcode_atts );

		$icon_inner_markup = Crea_ThemePlugin_Icon_Mixin::get_instance()->get_render( $atts );

		$inner_wrapper_classes = $this->get_inner_wrapper_classes( $shortcode_atts );
		
		$sharing_anchor_tag_props = $this->get_share_link_props_according_to_type( $sharing_type );

		ob_start();
        
        $markup_file_path = $this->get_markup_file_path();
		if ( file_exists( $markup_file_path ) ) {
			include $markup_file_path;
        }

		$content = ob_get_clean();

		return $content;
	}
	
	public function loadCssAndJs() {
		wp_register_style( 'theme-icons', get_template_directory_uri() . '/assets/css/theme-icons.css', false );
		wp_register_style( 'crea-vc-social-share-button', plugins_url( 'assets/vc_extend.css', __FILE__ ) );
	}
	
	public function loadAdminCssAndJs() {
		wp_enqueue_style( 'theme-icons', get_template_directory_uri() . '/assets/css/theme-icons.css', false );
	}

    private function generate_unique_id() {
        $any_random_number = wp_rand( 1, 10000 );
        $this->unique_random_number = (string) $any_random_number;
	}

	protected function get_share_link_props_according_to_type( $sharing_type ) {
		// https://forum.webflow.com/t/dynamic-share-buttons-for-different-social-media/30991
		// http://www.sharelinkgenerator.com/
		$sharing_anchor_tag_props = (object) array(
			'href' => '',
			'title' => '',
			'onclick' => ''
		);	// https://www.simonholywell.com/post/2016/11/quick-way-to-create-php-stdclass/

		switch ( $sharing_type ) {
			case 'facebook':
				$sharing_anchor_tag_props->href = 'https://www.facebook.com/sharer/sharer.php?u=&t=';
				$sharing_anchor_tag_props->title = esc_attr__( 'Share on Facebook', 'airpro' );
				$sharing_anchor_tag_props->onclick =
					"window.open('https://www.facebook.com/sharer/sharer.php?u=' + encodeURIComponent(document.URL) + '&t=' + encodeURIComponent(document.URL)); return false;";
				break;
			case 'twitter':
				$sharing_anchor_tag_props->href = 'https://twitter.com/intent/tweet?';
				$sharing_anchor_tag_props->title = esc_attr__( 'Tweet', 'airpro' );
				$sharing_anchor_tag_props->onclick =
					"window.open('https://twitter.com/intent/tweet?text=%20Check%20up%20this%20awesome%20content!%20' + encodeURIComponent(document.title) + ':%20 ' + encodeURIComponent(document.URL)); return false;";
				break;
			case 'googleplus':
				$sharing_anchor_tag_props->href = 'https://plus.google.com/share?url=';
				$sharing_anchor_tag_props->title = esc_attr__( 'Share on Google+', 'airpro' );
				$sharing_anchor_tag_props->onclick =
					"window.open('https://plus.google.com/share?url=' + encodeURIComponent(document.URL)); return false;";
				break;
			case 'pinterest':
				$sharing_anchor_tag_props->href = 'https://pinterest.com/pin/create/button/?url=&media=&description=';
				$sharing_anchor_tag_props->title = esc_attr__( 'Pin it', 'airpro' );
				$sharing_anchor_tag_props->onclick =
					"window.open('https://pinterest.com/pin/create/button/?url=&media=' + encodeURIComponent(document.URL) + '&description=' + encodeURIComponent(document.title)); return false;";
				break;
			case 'tumblr':
				$sharing_anchor_tag_props->href = 'http://www.tumblr.com/share?v=3&u=&t=&s=';
				$sharing_anchor_tag_props->title = esc_attr__( 'Post to Tumblr', 'airpro' );
				$sharing_anchor_tag_props->onclick =
					"window.open('http://www.tumblr.com/share?v=3&u=' + encodeURIComponent(document.URL) + '&t=' + encodeURIComponent(document.title)); return false;";
				break;
			case 'linkedin':
				$sharing_anchor_tag_props->href = 'https://www.linkedin.com/shareArticle?mini=true&url=&title=&summary=&source=';
				$sharing_anchor_tag_props->title = esc_attr__( 'Share on Facebook', 'airpro' );
				$sharing_anchor_tag_props->onclick =
					"window.open('https://www.linkedin.com/shareArticle?mini=true&url=' + encodeURIComponent(document.URL) + '&title=' + encodeURIComponent(document.title)); return false;";
				break;
			case 'reddit':
				$sharing_anchor_tag_props->href = 'http://www.reddit.com/submit?url=&title=';
				$sharing_anchor_tag_props->title = esc_attr__( 'Share on Facebook', 'airpro' );
				$sharing_anchor_tag_props->onclick =
					"window.open('http://www.reddit.com/submit?url=' + encodeURIComponent(document.URL) + '&title=' + encodeURIComponent(document.title)); return false;";
				break;
			case 'email':
				$sharing_anchor_tag_props->href = 'mailto:?subject=&body=:%20';
				$sharing_anchor_tag_props->title = esc_attr__( 'E-Mail', 'airpro' );
				$body_text = esc_attr__( 'Thought you might be interested in this:', 'airpro' );
				$sharing_anchor_tag_props->onclick =
					"window.open('mailto:?subject=' + encodeURIComponent(document.title) + '&body="
						. $body_text
						. "%0A%0A' + encodeURIComponent(document.URL)); return false;";
				break;
		}

		return $sharing_anchor_tag_props;
	}

	protected function get_default_settings_values() {
		$default_icon_default_settings_values = Crea_ThemePlugin_Icon_Mixin::get_instance()->get_default_settings_values();

		return array_merge(
			array(
				'sharing_type'  => '',
				'position_absolute'  => '',
				'link'               => '',
				'alignment'          => 'left',	// left here for backward-compatibility
                'float_inside_container'          => '',
				'el_class'           => ''
			),

			$default_icon_default_settings_values,
			array(
				// Design Options
				'css'                => ''
			)
		);
	}

    private function enqueue_js_css_if_shortcode_found_on_page( $shortcode_atts ) {
		wp_enqueue_style( 'theme-icons' );
		wp_enqueue_style( 'crea-vc-social-share-button' );
		if ( ! empty( $shortcode_atts[ 'fontawesome_icon' ] ) ) {
			wp_enqueue_style( 'font-awesome' );
		}

		$inline_css = $this->get_inline_styles_based_on_settings( $shortcode_atts );

		wp_add_inline_style( 'crea-vc-social-share-button', implode( ' ', $inline_css ) );
	}
	
	private function get_inline_styles_based_on_settings( $shortcode_atts ) {
		$inline_css = array();
		
		if ( $shortcode_atts[ 'position_absolute' ] == 'true' ) {
			$inline_css[] = sprintf( '.crea-vc-social-share-button-%1$s { position: absolute; }',
				$this->unique_random_number
			);
		}

		$icon_inline_css = Crea_ThemePlugin_Icon_Mixin::get_instance()->get_inline_styles_based_on_settings(
			sprintf( '.crea-vc-social-share-button-%1$s .crea-vc-themeicon-icon', $this->unique_random_number ),
			$shortcode_atts
		);

		return array_merge(
			$inline_css,
			$icon_inline_css
		);
	}

    private function get_selected_icon( $shortcode_atts ) {
		$res = $shortcode_atts[ 'theme_icon' ];
		if ( empty( $res ) ) {
			$res = $shortcode_atts[ 'fontawesome_icon' ];
		}

		return $res;
	}

	private function get_icon_classes( $params ) {

		$default_icon_classes = Crea_ThemePlugin_Icon_Mixin::get_instance()->get_icon_classes( $params );

		$classes = explode( ' ', $default_icon_classes );
		$classes[] = 'crea-vc-themeicon-icon';
		$classes[] = 'crea-vc-themeicon-subgroup';
		$classes[] = 'crea-vc-themeicon-subgroup-icon';

		return implode( ' ', $classes );
	}

	private function get_inner_wrapper_classes( $params ) {
		$classes = array (
            'crea-vc-themeicon-inner-wrapper'
        );

		return implode( ' ', $classes );
	}

	private function get_main_addon_container_classes( $params ) {
		$classes = array(
			'crea-vc-social-share-button crea-vc-social-share-button-' . $this->unique_random_number,
			vc_shortcode_custom_css_class( $params[ 'css' ], ' ' )
		);

		if ( $params[ 'float_inside_container' ] ) {
			$classes[] = 'crea-content-flex-container-float-' . $params[ 'float_inside_container' ];
		}
		elseif ( $params[ 'alignment' ] ) {	// left here for backward-compatibility
			$classes[] = 'crea-content-flex-container-float-' . $params[ 'alignment' ];
		}

		if ( ! empty( Crea_ThemePlugin_Icon_Mixin::get_instance()->get_selected_icon( $params ) ) ) {
			$classes[] = 'crea-vc-icon-has-icon';
		}

		return implode( ' ', $classes );
	}

	protected function get_markup_file_path() {
		return SCP_PLUGIN_PATH . '/vc-addons/theme-social-share-button/templates/_item.php';
	}
}

new Scp_Theme_Social_share_button();
